!*************************************************************************************************
! Start up procedures for selected sites
! (read common parameters and climate data)
!*************************************************************************************************
   Include 'modules.f90'        
   Include 'main.f90'           
   Include 'initialize.f90'     
   Include 'metabolic.f90'      
   Include 'output.f90'         
   Include 'physics.f90'        
   Include 'population_regu.f90'
   Include 'spatial_calc.f90'   
   Include 'etc.f90'            
   
PROGRAM start_point

!_____________ Set Variables
!Namespace
   USE data_structure
   implicit none
   
!Climate data
   integer year_climate_max !year length of the climate data
   
   real,allocatable,dimension(:,:)  ::tmp_air   !2m air temperature (Celcius)
   real,allocatable,dimension(:,:)  ::tmp_soil1 !soil temperature   0- 10cm depth (Celcius)
   real,allocatable,dimension(:,:)  ::tmp_soil2 !soil temperature  10-200cm depth (Celcius)
   real,allocatable,dimension(:,:)  ::tmp_soil3 !soil temperature 200-300cm depth (Celcius)
   real,allocatable,dimension(:,:)  ::cloud     !total cloudiness (fraction)
   real,allocatable,dimension(:,:)  ::prec      !precipitation (mm day-1)
   real,allocatable,dimension(:,:)  ::humid     !specific humidity (kg kg-1)
   real,allocatable,dimension(:,:)  ::wind      !wind velocity (m s-1)
   real,allocatable,dimension(:,:)  ::tmp_air_dr !daily range of air temperature (Celcius)
   
!Location data
   integer Mask         !Land ocean mask (1:land, 0:ocean)
   real    ALT          !altitude (m above MSL)
   real    Albedo_soil0 !albedo, default
   real    W_fi         !filed capacity   (m3/m3, 0.0 -> 1.0)
   real    W_wilt       !wilting point    (m3/m3, 0.0 -> 1.0)
   real    W_sat        !saturate point   (m3/m3, 0.0 -> 1.0)
   real    W_mat        !matrix potential (m, -0.0001 -> -3.0)
   
!Others
   real    LAT, LON       !latitude and logitude for simulate
   integer point          !
   integer i, j, k, count !for general usage
   real    x              !for general usage
   
!_____________ Set location
!  LAT    north:+, south:- (decimalized)
!  LON    east:+, west:-   (decimalized)
   !Pasoh
    LAT    = 2.97  
    LON    = 102.3 
   
!Set cordinate variables
   point = (90-int(LAT)-1)*360 + int(LON+180) + 1
   
!_____________ Read Parameters
!Read Parameter files
   open (1, file='parameter.txt', action='READ', status='OLD')
      read ( unit=1, nml=Control)       
      read ( unit=1, nml=PFT_type)      
      read ( unit=1, nml=Respiration)   
      read ( unit=1, nml=Turnover_n)    
      read ( unit=1, nml=Metabolic)     
      read ( unit=1, nml=Assimilation)  
      read ( unit=1, nml=Dynamics)      
      read ( unit=1, nml=Disturbance)   
      read ( unit=1, nml=Soil_resp)     
   close (1)
   
!Read Location data
   open ( File_no(1), file=Fn_location, status='OLD')
   do i=1, point
      read(File_no(1),*) Mask, ALT, Albedo_soil0, W_sat, W_fi, W_mat, W_wilt
   end do
   close( File_no(1) )
   
   !data processing
   if (W_fi   > W_sat ) W_fi   = W_sat
   if (W_wilt > W_sat ) W_wilt = W_sat
   
!_____________ Read Climate Data
!Scan climate data length
   count = 0
   open (File_no(1), file=Fn_climate, status='OLD')
   do i=1,Day_in_Year * 10000
      count = count + 1
      read(File_no(1),*,end=100)
   enddo
   100 continue
   close (File_no(1))
   year_climate_max = int(count/Day_in_Year)
   
!Set sizes of allocatable climate data table
   allocate (tmp_air   (Day_in_Year, year_climate_max)     )
   allocate (tmp_soil1 (Day_in_Year, year_climate_max)     )
   allocate (tmp_soil2 (Day_in_Year, year_climate_max)     )
   allocate (tmp_soil3 (Day_in_Year, year_climate_max)     )
   allocate (cloud     (Day_in_Year, year_climate_max)     )
   allocate (prec      (Day_in_Year, year_climate_max)     )
   allocate (humid     (Day_in_Year, year_climate_max)     )
   allocate (wind      (Day_in_Year, year_climate_max)     )
   allocate (tmp_air_dr(Day_in_Year, year_climate_max)     )
   
!Read Climatic data
   open ( File_no(1), file=Fn_climate, status='OLD')
   do i=1, year_climate_max
   do j=1, Day_in_Year
      read (File_no(1),*) tmp_air(j,i), tmp_soil1(j,i), tmp_soil2(j,i), tmp_soil3(j,i), &
                          prec(j,i), cloud(j,i), wind(j,i), humid(j,i), tmp_air_dr(j,i)
   enddo
   enddo
   close (File_no(1))
   
!_____________ Display Simulation Conditions
   !Print location properties
   write (*,*)
   write (*,*) '*********  Coodinate Configurations  *********'
   write (*,*) 'Latitude, Longtitude   :', LAT, LON
   write (*,*) 'Point nomal            :', point
   write (*,*)
   
   !Print soil properties
   write (*,*) '*********  Location properties  *********'
   write (*,*) 'Altitude    :', ALT         
   write (*,*) 'Albedo_soil0:', Albedo_soil0
   write (*,*) 'W_sat       :', W_sat       
   write (*,*) 'W_fi        :', W_fi        
   write (*,*) 'W_wilt      :', W_wilt      
   write (*,*)                              
   
   !Print climate properties
   x = real(Day_in_Year * year_climate_max)
   
   write (*,*) '*********  Wether statistics (annual mean of the first year)  *********'
   write (*,*) '2m air temperature       (Celsius) :', sum(tmp_air   (:,:)) / x
   write (*,*) 'soil temperature 1       (Celsius) :', sum(tmp_soil1 (:,:)) / x
   write (*,*) 'soil temperature 2       (Celsius) :', sum(tmp_soil2 (:,:)) / x
   write (*,*) 'soil temperature 3       (Celsius) :', sum(tmp_soil3 (:,:)) / x
   write (*,*) 'precipitation            (mm/year) :', sum(prec      (:,:)) /real(year_climate_max)
   write (*,*) 'cloud                    (fraction):', sum(cloud     (:,:)) / x
   write (*,*) 'humidity                 (kg/kg)   :', sum(humid     (:,:)) / x
   write (*,*) 'wind                     (m/s)     :', sum(wind      (:,:)) / x
   write (*,*) 'daily range of air temp. (Celsius) :', sum(tmp_air_dr(:,:)) / x
   write (*,*) 
  
!_____________ Simulation
   !Call simulation loop
   IF (Mask==0 .or. Albedo_soil0<=0.0 .or. W_sat<=0.0 .or. W_fi<=0.0 .or. W_wilt<=0.0 ) then
      write(*,*) 'Error: Invalid location properties'
   ELSE
      write (*,*) '*********  Now simulating  *********'
      Call main_loop ( &
      LAT, LON, year_climate_max, &
      tmp_air(:,:), tmp_soil1(:,:), tmp_soil2(:,:), tmp_soil3(:,:), &
      cloud(:,:), prec(:,:), humid(:,:), wind(:,:), &
      ALT, Albedo_soil0, W_fi, W_wilt, W_sat, W_mat )
      write (*,*) '*********  Done  *********'
   ENDIF
   
   STOP
   
END PROGRAM start_point
